@@ -71,13 +71,18 @@ void	config(int argc, char **argv)
                                 memset (MonitorDomainName, 0x00, 128);
                                 memcpy (MonitorDomainName, pnt, strlen(pnt));
                         }
-                        else if (!memcmp (buff, "SERVER_NAME", 11))
+                        else if (!memcmp (buff, "TRUST_NAME", 10))
                         {
 				len = strlen(pnt);
 				if (len > 16) len = 16;
                                 memset (TrustName, 0x20, 16);
                                 memcpy (TrustName, pnt, len);
                         }
+                        else if (!memcmp (buff, "TRUST_DB_DOMAIN_NAME", 20))
+                        {
+                                memset (TrustDbDomainName, 0x00, 128);
+                                memcpy (TrustDbDomainName, pnt, strlen(pnt));
+                        }
 		}
 	}
 	fclose (config_file);
