@@ -39,7 +39,6 @@ int	login(int socket)
 	if (RepeaterCall[7] == 0x20) return 0;		/* no module name */
 
 	call[7] = 0x00;
-
 	for (n = 0 ; n < 7 ; n++)
 	{
 		if (call[n] == 0x20) call[n] = 0x00;  
@@ -64,7 +63,7 @@ int	login(int socket)
 
         while (fgets (line, sizeof line , shadow))
         {
-                if (memcmp (call, line, strlen(call)) == 0)
+                if (!memcmp (&call, &line, strlen(call)))
 		{
 			k = strlen(call) + 1;
 			for (n = k ; n < 256 ; n++)
@@ -83,7 +82,6 @@ int	login(int socket)
 			else return 1;
 		}
         }
-
 	return 0;
 
 }
