@@ -1,3 +1,7 @@
+/*
+
+*/
+
 #include	"trust.h"
 #include	"shm.h"
 #include	"repeater.h"
@@ -12,6 +16,7 @@ int Repeater(void)
 	int	n;
 	int	numrcv;
 	int	opt;
+	int	KeepAliveTimer;
         fd_set  readOk, Mask;
         struct  timeval timeout;
 
@@ -54,9 +59,11 @@ int Repeater(void)
                 send_msg.protocol = G3;
                 dbAddr.sin_family = AF_INET;
                 dbAddr.sin_port = dbOutPort;
-                dbAddr.sin_addr.s_addr = inet_addr("127.0.0.1");
-                ret = sendto (dbSock, (char *)&send_msg, sizeof (struct shm_form), 0,
-                                (struct sockaddr *)&dbAddr, sizeof(dbAddr));
+                dbAddr.sin_addr = dbIP;
+                sendto (dbSock, (char *)&send_msg, 
+			sizeof (struct shm_form), 0,
+                        (struct sockaddr *)&dbAddr, sizeof(dbAddr));
+		KeepAliveTimer = 0;
 
 		while(1){
 			readOk = Mask;
@@ -155,6 +162,20 @@ int Repeater(void)
                                                         }
                                                 }
 					}
+                        		if (KeepAliveTimer++ > 2000)
+                        		{
+                                		memcpy (send_msg.trust_name, TrustName, 16);
+                                		memcpy (send_msg.rep_name, RepeaterCall, 8);
+                                		send_msg.type = RepActive;
+                                		send_msg.protocol = G3;
+                                		dbAddr.sin_family = AF_INET;
+                                		dbAddr.sin_port = dbOutPort;
+                                		dbAddr.sin_addr = dbIP;
+                                		sendto (dbSock, (char *)&send_msg,
+                                        		sizeof (struct shm_form), 0,
+                                        		(struct sockaddr *)&dbAddr, sizeof(dbAddr));
+                                		KeepAliveTimer = 0;
+                        		}
                                 	break;
 
                        	 	default:
@@ -199,7 +220,7 @@ int DoCommand(struct repMsg com)
                	send_msg.protocol = com.reqConnect.protocol;
                 dbAddr.sin_family = AF_INET;
                 dbAddr.sin_port = dbOutPort;
-                dbAddr.sin_addr.s_addr = inet_addr("127.0.0.1");
+                dbAddr.sin_addr = dbIP;
 		ret = sendto (dbSock, (char *)&send_msg, sizeof (struct shm_form), 0,
 				(struct sockaddr *)&dbAddr, sizeof(dbAddr));
         }
