@@ -58,6 +58,7 @@ char	*argv[];
 int InitSocket(void)
 {
 	struct	sockaddr_in	me;
+        struct  hostent *hp;
 	int	opt;
 
 	DB(fprintf(stderr,"InitSocket\n"));
@@ -115,6 +116,9 @@ int InitSocket(void)
 	}
         DB(fprintf(stderr,"shmat:OK\n"));
 
+        hp = gethostbyname(TrustDbDomainName);
+        memcpy (&dbIP, hp->h_addr_list[0], hp->h_length);
+
 	return(0);
 }
 
